@@ -104,10 +104,10 @@ const char *Con_Quakebar (int len)
 Con_ToggleConsole_f
 ================
 */
+extern int history_line; //johnfitz
+
 void Con_ToggleConsole_f (void)
 {
-	extern int history_line; //johnfitz
-
 	if (key_dest == key_console)
 	{
 		if (cls.state == ca_connected)
@@ -950,11 +950,15 @@ void Con_TabComplete (void)
 		const char *matched_map = BuildMapList(partial);
 		if (!*matched_map)
 			return;
-		Q_strcpy (partial, matched_map);
-		Q_strcpy (c, partial);
+		q_strlcpy (partial, matched_map, MAXCMDLINE);
+		*c = '\0';
+		q_strlcat (key_lines[edit_line], partial, MAXCMDLINE);
 		key_linepos = c - key_lines[edit_line] + Q_strlen(matched_map); //set new cursor position
+		if (key_linepos >= MAXCMDLINE)
+			key_linepos = MAXCMDLINE - 1;
 		// if only one match, append a space
-		if ((key_lines[edit_line][key_linepos] == 0) && map_singlematch)
+		if (key_linepos < MAXCMDLINE - 1 &&
+		    key_lines[edit_line][key_linepos] == 0 && map_singlematch)
 		{
 			key_lines[edit_line][key_linepos] = ' ';
 			key_linepos++;
@@ -976,7 +980,7 @@ void Con_TabComplete (void)
 	mark = Hunk_LowMark();
 	if (!key_tabpartial[0]) //first time through
 	{
-		Q_strcpy (key_tabpartial, partial);
+		q_strlcpy (key_tabpartial, partial, MAXCMDLINE);
 		BuildTabList (key_tabpartial);
 
 		if (!tablist)
@@ -1008,26 +1012,31 @@ void Con_TabComplete (void)
 
 		//find current match -- can't save a pointer because the list will be rebuilt each time
 		t = tablist;
+		match = keydown[K_SHIFT] ? t->prev->name : t->name;
 		do
 		{
 			if (!Q_strcmp(t->name, partial))
+			{
+				match = keydown[K_SHIFT] ? t->prev->name : t->next->name;
 				break;
+			}
 			t = t->next;
 		} while (t != tablist);
-
-		//use prev or next to find next match
-		match = keydown[K_SHIFT] ? t->prev->name : t->next->name;
 	}
 	Hunk_FreeToLowMark(mark); //it's okay to free it here because match is a pointer to persistent data
 
 // insert new match into edit line
-	Q_strcpy (partial, match); //first copy match string
-	Q_strcat (partial, key_lines[edit_line] + key_linepos); //then add chars after cursor
-	Q_strcpy (c, partial); //now copy all of this into edit line
+	q_strlcpy (partial, match, MAXCMDLINE); //first copy match string
+	q_strlcat (partial, key_lines[edit_line] + key_linepos, MAXCMDLINE); //then add chars after cursor
+	*c = '\0';	//now copy all of this into edit line
+	q_strlcat (key_lines[edit_line], partial, MAXCMDLINE);
 	key_linepos = c - key_lines[edit_line] + Q_strlen(match); //set new cursor position
+	if (key_linepos >= MAXCMDLINE)
+		key_linepos = MAXCMDLINE - 1;
 
 // if cursor is at end of string, let's append a space to make life easier
-	if (key_lines[edit_line][key_linepos] == 0 && bash_singlematch)
+	if (key_linepos < MAXCMDLINE - 1 &&
+	    key_lines[edit_line][key_linepos] == 0 && bash_singlematch)
 	{
 		key_lines[edit_line][key_linepos] = ' ';
 		key_linepos++;
@@ -1055,13 +1064,14 @@ Con_DrawNotify
 Draws the last few lines of output transparently over the game top
 ================
 */
+extern	char chat_buffer[];
+
 void Con_DrawNotify (void)
 {
 	int	x, v;
 	char	*text;
 	int	i;
 	float	time;
-	extern	char chat_buffer[];
 
 	GL_SetCanvas (CANVAS_CONSOLE); //johnfitz
 	v = vid.conheight; //johnfitz
@@ -1134,11 +1144,12 @@ Con_DrawInput -- johnfitz -- modified to allow insert editing
 The input line scrolls horizontally if typing goes beyond the right edge
 ================
 */
+extern	qpic_t *pic_ovr, *pic_ins; //johnfitz -- new cursor handling
+extern	double key_blinktime;
+extern	int key_insert;
+
 void Con_DrawInput (void)
 {
-	extern	qpic_t *pic_ovr, *pic_ins; //johnfitz -- new cursor handling
-	extern	double key_blinktime;
-	extern	int key_insert;
 	int	i, ofs;
 
 	if (key_dest != key_console && !con_forcedup)
