@@ -26,9 +26,14 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "cfgfile.h"
 #include "bgmusic.h"
 #include "resource.h"
+#if defined(SDL_FRAMEWORK) || defined(NO_SDL_CONFIG)
+#include <SDL/SDL.h>
+#else
 #include "SDL.h"
+#endif
 
 #define MAX_MODE_LIST	600 //johnfitz -- was 30
+#define MAX_BPPS_LIST	5
 #define VID_ROW_SIZE	3
 #define WARP_WIDTH		320
 #define WARP_HEIGHT		200
@@ -129,7 +134,6 @@ static cvar_t	vid_bpp = {"vid_bpp", "16", CVAR_ARCHIVE};
 static cvar_t	vid_vsync = {"vid_vsync", "0", CVAR_ARCHIVE};
 //johnfitz
 
-cvar_t		_windowed_mouse = {"_windowed_mouse","1", CVAR_ARCHIVE};
 cvar_t		vid_gamma = {"gamma", "1", CVAR_ARCHIVE}; //johnfitz -- moved here from view.c
 
 //==========================================================================
@@ -193,18 +197,12 @@ VID_Gamma_f -- callback when the cvar changes
 */
 static void VID_Gamma_f (cvar_t *var)
 {
-	static float oldgamma;
 	int i;
 
-	if (vid_gamma.value == oldgamma)
-		return;
-
-	oldgamma = vid_gamma.value;
-
 	for (i = 0; i < 256; i++)
 	{
 		vid_gamma_red[i] =
-			CLAMP(0, (int) (255 * pow ((i+0.5)/255.5, vid_gamma.value) + 0.5), 255) << 8;
+			CLAMP(0, (int) (255 * pow((i + 0.5)/255.5, var->value) + 0.5), 255) << 8;
 		vid_gamma_green[i] = vid_gamma_red[i];
 		vid_gamma_blue[i] = vid_gamma_red[i];
 	}
@@ -263,26 +261,11 @@ static int VID_SetMode (int modenum)
 
 	if (modelist[modenum].type == MODE_WINDOWED)
 	{
-		if (_windowed_mouse.value && key_dest == key_game)
-		{
-			draw_context = SDL_SetVideoMode(modelist[modenum].width,
-							modelist[modenum].height,
-							modelist[modenum].bpp, flags);
-		}
-		else
-		{
-			draw_context = SDL_SetVideoMode(modelist[modenum].width,
-							modelist[modenum].height,
-							modelist[modenum].bpp, flags);
-		}
 		modestate = MODE_WINDOWED;
 	}
 	else if (modelist[modenum].type == MODE_FULLSCREEN_DEFAULT)
 	{
 		flags |= SDL_FULLSCREEN;
-		draw_context = SDL_SetVideoMode(modelist[modenum].width,
-						modelist[modenum].height,
-						modelist[modenum].bpp, flags);
 		modestate = MODE_FULLSCREEN_DEFAULT;
 	}
 	else
@@ -290,6 +273,9 @@ static int VID_SetMode (int modenum)
 		Sys_Error ("VID_SetMode: Bad mode type in modelist");
 	}
 
+	draw_context = SDL_SetVideoMode(modelist[modenum].width,
+					modelist[modenum].height,
+					modelist[modenum].bpp, flags);
 	if (!draw_context)
 	{
 		Sys_Error ("Couldn't set video mode");
@@ -421,10 +407,17 @@ static void VID_Restart (void)
 //
 // keep cvars in line with actual mode
 //
-	Cvar_SetQuick (&vid_width, va("%i", modelist[vid_default].width));
-	Cvar_SetQuick (&vid_height, va("%i", modelist[vid_default].height));
-	Cvar_SetQuick (&vid_bpp, va("%i", modelist[vid_default].bpp));
+	Cvar_SetValueQuick (&vid_width, modelist[vid_default].width);
+	Cvar_SetValueQuick (&vid_height, modelist[vid_default].height);
+	Cvar_SetValueQuick (&vid_bpp, modelist[vid_default].bpp);
 	Cvar_SetQuick (&vid_fullscreen, (windowed) ? "0" : "1");
+//
+// update mouse grab
+//
+	if (vid_fullscreen.value)
+		IN_Activate();
+	else if (key_dest == key_console || key_dest == key_menu)
+		IN_Deactivate(vid.type == MODE_WINDOWED);
 }
 
 /*
@@ -450,9 +443,9 @@ static void VID_Test (void)
 	if (!SCR_ModalMessage("Would you like to keep this\nvideo mode? (y/n)\n", 5.0f))
 	{
 		//revert cvars and mode
-		Cvar_SetQuick (&vid_width, va("%i", oldmode.width));
-		Cvar_SetQuick (&vid_height, va("%i", oldmode.height));
-		Cvar_SetQuick (&vid_bpp, va("%i", oldmode.bpp));
+		Cvar_SetValueQuick (&vid_width, oldmode.width);
+		Cvar_SetValueQuick (&vid_height, oldmode.height);
+		Cvar_SetValueQuick (&vid_bpp, oldmode.bpp);
 		Cvar_SetQuick (&vid_fullscreen, (oldmode.type == MODE_WINDOWED) ? "0" : "1");
 		VID_Restart ();
 	}
@@ -468,9 +461,9 @@ static void VID_Unlock (void)
 	vid_locked = false;
 
 	//sync up cvars in case they were changed during the lock
-	Cvar_SetQuick (&vid_width, va("%i", modelist[vid_default].width));
-	Cvar_SetQuick (&vid_height, va("%i", modelist[vid_default].height));
-	Cvar_SetQuick (&vid_bpp, va("%i", modelist[vid_default].bpp));
+	Cvar_SetValueQuick (&vid_width, modelist[vid_default].width);
+	Cvar_SetValueQuick (&vid_height, modelist[vid_default].height);
+	Cvar_SetValueQuick (&vid_bpp, modelist[vid_default].bpp);
 	Cvar_SetQuick (&vid_fullscreen, (windowed) ? "0" : "1");
 }
 
@@ -837,14 +830,6 @@ ClearAllStates
 */
 static void ClearAllStates (void)
 {
-	int		i;
-
-// send an up event for each key, to make sure the server clears them all
-	for (i = 0; i < 256; i++)
-	{
-		Key_Event (i, false);
-	}
-
 	Key_ClearStates ();
 	IN_ClearStates ();
 }
@@ -1044,7 +1029,7 @@ static void VID_InitFullDIB (void)
 	SDL_Rect	**modes;
 	Uint32		flags;
 	int		i, j, k, modenum, originalnummodes, existingmode;
-	int		bpps[3] = {16, 24, 32}; // enumerate >8 bpp modes
+	int		bpps[] = {16, 24, 32}; // enumerate >8 bpp modes
 
 	originalnummodes = nummodes;
 	modenum = 0;
@@ -1052,7 +1037,7 @@ static void VID_InitFullDIB (void)
 
 	// enumerate fullscreen modes
 	flags = SDL_DEFAULT_FLAGS | SDL_FULLSCREEN;
-	for (i = 0; i < 3; i++)
+	for (i = 0; i < (int)(sizeof(bpps)/sizeof(bpps[0])); i++)
 	{
 		if (nummodes >= MAX_MODE_LIST)
 			break;
@@ -1147,7 +1132,6 @@ void	VID_Init (void)
 	Cvar_SetCallback (&vid_height, VID_Changed_f);
 	Cvar_SetCallback (&vid_bpp, VID_Changed_f);
 //	Cvar_RegisterVariable (&vid_refreshrate); //johnfitz
-	Cvar_RegisterVariable (&_windowed_mouse);
 
 	Cmd_AddCommand ("vid_unlock", VID_Unlock); //johnfitz
 	Cmd_AddCommand ("vid_restart", VID_Restart); //johnfitz
@@ -1354,7 +1338,7 @@ void	VID_Toggle (void)
 		goto vrestart;
 	if (SDL_WM_ToggleFullScreen(draw_context) == 1)
 	{
-		qboolean was_changed = vid_changed;
+		qboolean was_changed;
 
 		Sbar_Changed ();	// Sbar seems to need refreshing
 		windowed = !windowed;
@@ -1368,12 +1352,18 @@ void	VID_Toggle (void)
 		was_changed = vid_changed;
 		Cvar_SetQuick (&vid_fullscreen, vid_fullscreen.value ? "0" : "1");
 		vid_changed = was_changed;
+
+		// update mouse grab
+		if (vid_fullscreen.value)
+			IN_Activate();
+		else if (key_dest == key_console || key_dest == key_menu)
+			IN_Deactivate(vid.type == MODE_WINDOWED);
 	}
 	else
 	{
 		vid_toggle_works = false;
-		Con_Printf ("ToggleFullScreen failed, attempting VID_Restart\n");
-vrestart:
+		Con_DPrintf ("ToggleFullScreen failed, attempting VID_Restart\n");
+	vrestart:
 		Cvar_SetQuick (&vid_fullscreen, vid_fullscreen.value ? "0" : "1");
 		Cbuf_AddText ("vid_restart\n");
 	}
@@ -1388,9 +1378,9 @@ void VID_SyncCvars (void)
 {
 	int swap_control;
 
-	Cvar_SetQuick (&vid_width, va("%i", modelist[vid_default].width));
-	Cvar_SetQuick (&vid_height, va("%i", modelist[vid_default].height));
-	Cvar_SetQuick (&vid_bpp, va("%i", modelist[vid_default].bpp));
+	Cvar_SetValueQuick (&vid_width, modelist[vid_default].width);
+	Cvar_SetValueQuick (&vid_height, modelist[vid_default].height);
+	Cvar_SetValueQuick (&vid_bpp, modelist[vid_default].bpp);
 	Cvar_SetQuick (&vid_fullscreen, (windowed) ? "0" : "1");
 
 	if (SDL_GL_GetAttribute(SDL_GL_SWAP_CONTROL, &swap_control) == 0)
@@ -1415,7 +1405,7 @@ typedef struct {
 static vid_menu_mode vid_menu_modes[MAX_MODE_LIST];
 static int vid_menu_nummodes = 0;
 
-static int vid_menu_bpps[4];
+static int vid_menu_bpps[MAX_BPPS_LIST];
 static int vid_menu_numbpps = 0;
 
 #if 0
@@ -1468,6 +1458,9 @@ static void VID_Menu_RebuildBppList (void)
 
 	for (i = 1; i < nummodes; i++) //start i at mode 1 because 0 is windowed mode
 	{
+		if (vid_menu_numbpps >= MAX_BPPS_LIST)
+			break;
+
 		//bpp list is limited to bpps available with current width/height
 		if (modelist[i].width != vid_width.value ||
 			modelist[i].height != vid_height.value)
@@ -1807,6 +1800,7 @@ VID_Menu_f
 */
 static void VID_Menu_f (void)
 {
+	IN_Deactivate(vid.type == MODE_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_video;
 	m_entersound = true;
