@@ -61,7 +61,7 @@ cvar_t	host_framerate = {"host_framerate","0",CVAR_NONE};	// set for slow motion
 cvar_t	host_speeds = {"host_speeds","0",CVAR_NONE};			// set for running times
 cvar_t	host_maxfps = {"host_maxfps", "72", CVAR_ARCHIVE}; //johnfitz
 cvar_t	host_timescale = {"host_timescale", "0", CVAR_NONE}; //johnfitz
-cvar_t	max_edicts = {"max_edicts", STR(DEF_EDICTS), CVAR_ARCHIVE}; //johnfitz
+cvar_t	max_edicts = {"max_edicts", "2048", CVAR_ARCHIVE}; //johnfitz
 
 cvar_t	sys_ticrate = {"sys_ticrate","0.05",CVAR_NONE}; // dedicated server
 cvar_t	serverprofile = {"serverprofile","0",CVAR_NONE};
@@ -81,6 +81,8 @@ cvar_t	developer = {"developer","0",CVAR_NONE};
 
 cvar_t	temp1 = {"temp1","0",CVAR_NONE};
 
+cvar_t	cfg_unbindall = {"cfg_unbindall", "1", CVAR_ARCHIVE}; //QuakeSpasm
+
 cvar_t devstats = {"devstats","0",CVAR_NONE}; //johnfitz -- track developer statistics that vary every frame
 
 devstats_t dev_stats, dev_peakstats;
@@ -93,16 +95,10 @@ Max_Edicts_f -- johnfitz
 */
 static void Max_Edicts_f (cvar_t *var)
 {
-	static float oldval = DEF_EDICTS; //must match the default value for max_edicts
-
 	//TODO: clamp it here?
-	if (max_edicts.value == oldval)
-		return;
 
 	if (cls.state == ca_connected || sv.active)
 		Con_Printf ("Changes to max_edicts will not take effect until the next time a map is loaded.\n");
-
-	oldval = max_edicts.value;
 }
 
 /*
@@ -280,6 +276,8 @@ void Host_InitLocal (void)
 
 	Cvar_RegisterVariable (&temp1);
 
+	Cvar_RegisterVariable (&cfg_unbindall); //QuakeSpasm
+
 	Host_FindMaxClients ();
 
 	host_time = 1.0;		// so a think at time 0 won't get called
@@ -310,6 +308,8 @@ void Host_WriteConfiguration (void)
 
 		VID_SyncCvars (); //johnfitz -- write actual current mode to config file, in case cvars were messed with
 
+		if (cfg_unbindall.value) fprintf (f, "unbindall\n"); //QuakeSpasm -- unbindall before loading stored bindings
+
 		Key_WriteBindings (f);
 		Cvar_WriteVariables (f);
 
