@@ -20,12 +20,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include "q_stdinc.h"
-#include "arch_def.h"
-#include "net_sys.h"	/* for net_defs.h */
-#include <dirent.h>
 #include "quakedef.h"
-#include "net_defs.h"	/* for struct qsocket_s details */
+#include <dirent.h>
 
 extern cvar_t	pausable;
 
@@ -533,7 +529,7 @@ void Host_Status_f (void)
 	{
 		if (!client->active)
 			continue;
-		seconds = (int)(net_time - client->netconnection->connecttime);
+		seconds = (int)(net_time - NET_QSocketGetTime(client->netconnection));
 		minutes = seconds / 60;
 		if (minutes)
 		{
@@ -545,7 +541,7 @@ void Host_Status_f (void)
 		else
 			hours = 0;
 		print_fn ("#%-2u %-16.16s  %3i  %2i:%02i:%02i\n", j+1, client->name, (int)client->edict->v.frags, hours, minutes, seconds);
-		print_fn ("   %s\n", client->netconnection->address);
+		print_fn ("   %s\n", NET_QSocketGetAddressString(client->netconnection));
 	}
 }
 
@@ -1632,7 +1628,7 @@ void Host_Spawn_f (void)
 		pr_global_struct->self = EDICT_TO_PROG(sv_player);
 		PR_ExecuteProgram (pr_global_struct->ClientConnect);
 
-		if ((Sys_DoubleTime() - host_client->netconnection->connecttime) <= sv.time)
+		if ((Sys_DoubleTime() - NET_QSocketGetTime(host_client->netconnection)) <= sv.time)
 			Sys_Printf ("%s entered the game\n", host_client->name);
 
 		PR_ExecuteProgram (pr_global_struct->PutClientInServer);
@@ -2072,7 +2068,7 @@ Host_Viewmodel_f
 void Host_Viewmodel_f (void)
 {
 	edict_t	*e;
-	model_t	*m;
+	qmodel_t	*m;
 
 	e = FindViewthing ();
 	if (!e)
@@ -2098,7 +2094,7 @@ void Host_Viewframe_f (void)
 {
 	edict_t	*e;
 	int		f;
-	model_t	*m;
+	qmodel_t	*m;
 
 	e = FindViewthing ();
 	if (!e)
@@ -2113,7 +2109,7 @@ void Host_Viewframe_f (void)
 }
 
 
-void PrintFrameName (model_t *m, int frame)
+void PrintFrameName (qmodel_t *m, int frame)
 {
 	aliashdr_t 			*hdr;
 	maliasframedesc_t	*pframedesc;
@@ -2134,7 +2130,7 @@ Host_Viewnext_f
 void Host_Viewnext_f (void)
 {
 	edict_t	*e;
-	model_t	*m;
+	qmodel_t	*m;
 
 	e = FindViewthing ();
 	if (!e)
@@ -2156,7 +2152,7 @@ Host_Viewprev_f
 void Host_Viewprev_f (void)
 {
 	edict_t	*e;
-	model_t	*m;
+	qmodel_t	*m;
 
 	e = FindViewthing ();
 	if (!e)
