@@ -21,7 +21,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "quakedef.h"
+#if defined(SDL_FRAMEWORK) || defined(NO_SDL_CONFIG)
+#include <SDL/SDL.h>
+#else
 #include "SDL.h"
+#endif
+
+static qboolean	prev_gamekey;
 
 #ifdef __APPLE__
 /* Mouse acceleration needs to be disabled on OS X */
@@ -35,8 +41,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <IOKit/hidsystem/event_status_driver.h>
 #endif
 
-static keydest_t	prev_key_dest;
-
 static qboolean	no_mouse = false;
 
 static int buttonremap[] =
@@ -206,7 +210,8 @@ void IN_Deactivate (qboolean free_cursor)
 
 void IN_Init (void)
 {
-	SDL_EnableUNICODE (0); /* frame updates will change this as key_dest changes */
+	prev_gamekey = ((key_dest == key_game && !con_forcedup) || m_keys_bind_grab);
+	SDL_EnableUNICODE (!prev_gamekey);
 	if (SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL) == -1)
 		Con_Printf("Warning: SDL_EnableKeyRepeat() failed.\n");
 
@@ -298,14 +303,15 @@ void IN_ClearStates (void)
 void IN_SendKeyEvents (void)
 {
 	SDL_Event event;
-	int sym, state;
-	int modstate;
+	int sym, state, modstate;
+	qboolean gamekey;
 
-	if (key_dest != prev_key_dest)
+	gamekey = ((key_dest == key_game && !con_forcedup) || m_keys_bind_grab);
+	if (gamekey != prev_gamekey)
 	{
-		SDL_EnableUNICODE((key_dest == key_console || key_dest == key_message));
+		prev_gamekey = gamekey;
 		Key_ClearStates();
-		prev_key_dest = key_dest;
+		SDL_EnableUNICODE(!gamekey);
 	}
 
 	while (SDL_PollEvent(&event))
@@ -316,15 +322,8 @@ void IN_SendKeyEvents (void)
 			if (event.active.state & (SDL_APPINPUTFOCUS|SDL_APPACTIVE))
 			{
 				if (event.active.gain)
-				{
-				/*	Sys_Printf("FOCUS GAIN\n");*/
 					S_UnblockSound();
-				}
-				else
-				{
-				/*	Sys_Printf("FOCUS LOSS\n");*/
-					S_BlockSound();
-				}
+				else	S_BlockSound();
 			}
 			break;
 
@@ -335,52 +334,45 @@ void IN_SendKeyEvents (void)
 				VID_Toggle();
 				break;
 			}
-			else if ((event.key.keysym.sym == SDLK_ESCAPE) &&
-				 (event.key.keysym.mod & KMOD_SHIFT))
+			if ((event.key.keysym.sym == SDLK_ESCAPE) &&
+			    (event.key.keysym.mod & KMOD_SHIFT))
 			{
 				Con_ToggleConsole_f();
 				break;
 			}
-
+		/* fallthrough */
 		case SDL_KEYUP:
 			sym = event.key.keysym.sym;
 			state = event.key.state;
 			modstate = SDL_GetModState();
 
-			switch (key_dest)
+			if (event.key.keysym.unicode != 0)
 			{
-			case key_game:
-				if ((event.key.keysym.unicode != 0) || (modstate & KMOD_SHIFT))
-				{	/* only use unicode for ~ and ` in game mode */
-					if ((event.key.keysym.unicode & 0xFF80) == 0)
-					{
-						if (((event.key.keysym.unicode & 0x7F) == '`') ||
-						    ((event.key.keysym.unicode & 0x7F) == '~') )
-							sym = event.key.keysym.unicode & 0x7F;
-					}
-				}
-				break;
-			case key_message:
-			case key_console:
-				if ((event.key.keysym.unicode != 0) || (modstate & KMOD_SHIFT))
+				if ((event.key.keysym.unicode & 0xFF80) == 0)
 				{
+					int usym = event.key.keysym.unicode & 0x7F;
+					if (modstate & KMOD_CTRL && usym < 32 && sym >= 32)
+					{
+						/* control characters */
+						if (modstate & KMOD_SHIFT)
+							usym += 64;
+						else	usym += 96;
+					}
 #if defined(__APPLE__) && defined(__MACH__)
 					if (sym == SDLK_BACKSPACE)
-						break;	/* avoid change to SDLK_DELETE */
+						usym = sym;	/* avoid change to SDLK_DELETE */
 #endif	/* Mac OS X */
 #if defined(__QNX__)
-					if ((sym == SDLK_BACKSPACE) || (sym == SDLK_RETURN))
-						break;	/* S.A: fixes QNX weirdness */
+					if (sym == SDLK_BACKSPACE || sym == SDLK_RETURN)
+						usym = sym;	/* S.A: fixes QNX weirdness */
 #endif	/* __QNX__ */
-					if ((event.key.keysym.unicode & 0xFF80) == 0)
-						sym = event.key.keysym.unicode & 0x7F;
-					/* else: it's an international character */
+					/* only use unicode for ` and ~ in game mode */
+					if (!gamekey || usym == '`' || usym == '~')
+						sym = usym;
 				}
-			/*	printf("You pressed %s (%d) (%c)\n", SDL_GetKeyName(sym), sym, sym);*/
-				break;
-			default:
-				break;
+				/* else: it's an international character */
 			}
+			/*printf("You pressed %s (%d) (%c)\n", SDL_GetKeyName(sym), sym, sym);*/
 
 			switch (sym)
 			{
@@ -469,95 +461,112 @@ void IN_SendKeyEvents (void)
 			case SDLK_LALT:
 				sym = K_ALT;
 				break;
+			case SDLK_RMETA:
+			case SDLK_LMETA:
+				sym = K_COMMAND;
+				break;
+			case SDLK_NUMLOCK:
+				if (gamekey)
+					sym = K_KP_NUMLOCK;
+				else	sym = 0;
+				break;
 			case SDLK_KP0:
-				if (modstate & KMOD_NUM)
-					sym = K_INS;
-				else
-					sym = SDLK_0;
+				if (gamekey)
+					sym = K_KP_INS;
+				else	sym = (modstate & KMOD_NUM) ? SDLK_0 : K_INS;
 				break;
 			case SDLK_KP1:
-				if (modstate & KMOD_NUM)
-					sym = K_END;
-				else
-					sym = SDLK_1;
+				if (gamekey)
+					sym = K_KP_END;
+				else	sym = (modstate & KMOD_NUM) ? SDLK_1 : K_END;
 				break;
 			case SDLK_KP2:
-				if (modstate & KMOD_NUM)
-					sym = K_DOWNARROW;
-				else
-					sym = SDLK_2;
+				if (gamekey)
+					sym = K_KP_DOWNARROW;
+				else	sym = (modstate & KMOD_NUM) ? SDLK_2 : K_DOWNARROW;
 				break;
 			case SDLK_KP3:
-				if (modstate & KMOD_NUM)
-					sym = K_PGDN;
-				else
-					sym = SDLK_3;
+				if (gamekey)
+					sym = K_KP_PGDN;
+				else	sym = (modstate & KMOD_NUM) ? SDLK_3 : K_PGDN;
 				break;
 			case SDLK_KP4:
-				if (modstate & KMOD_NUM)
-					sym = K_LEFTARROW;
-				else
-					sym = SDLK_4;
+				if (gamekey)
+					sym = K_KP_LEFTARROW;
+				else	sym = (modstate & KMOD_NUM) ? SDLK_4 : K_LEFTARROW;
 				break;
 			case SDLK_KP5:
-				sym = SDLK_5;
+				if (gamekey)
+					sym = K_KP_5;
+				else	sym = SDLK_5;
 				break;
 			case SDLK_KP6:
-				if (modstate & KMOD_NUM)
-					sym = K_RIGHTARROW;
-				else
-					sym = SDLK_6;
+				if (gamekey)
+					sym = K_KP_RIGHTARROW;
+				else	sym = (modstate & KMOD_NUM) ? SDLK_6 : K_RIGHTARROW;
 				break;
 			case SDLK_KP7:
-				if (modstate & KMOD_NUM)
-					sym = K_HOME;
-				else
-					sym = SDLK_7;
+				if (gamekey)
+					sym = K_KP_HOME;
+				else	sym = (modstate & KMOD_NUM) ? SDLK_7 : K_HOME;
 				break;
 			case SDLK_KP8:
-				if (modstate & KMOD_NUM)
-					sym = K_UPARROW;
-				else
-					sym = SDLK_8;
+				if (gamekey)
+					sym = K_KP_UPARROW;
+				else	sym = (modstate & KMOD_NUM) ? SDLK_8 : K_UPARROW;
 				break;
 			case SDLK_KP9:
-				if (modstate & KMOD_NUM)
-					sym = K_PGUP;
-				else
-					sym = SDLK_9;
+				if (gamekey)
+					sym = K_KP_PGUP;
+				else	sym = (modstate & KMOD_NUM) ? SDLK_9 : K_PGUP;
 				break;
 			case SDLK_KP_PERIOD:
-				if (modstate & KMOD_NUM)
-					sym = K_DEL;
-				else
-					sym = SDLK_PERIOD;
+				if (gamekey)
+					sym = K_KP_DEL;
+				else	sym = (modstate & KMOD_NUM) ? SDLK_PERIOD : K_DEL;
 				break;
 			case SDLK_KP_DIVIDE:
-				sym = SDLK_SLASH;
+				if (gamekey)
+					sym = K_KP_SLASH;
+				else	sym = SDLK_SLASH;
 				break;
 			case SDLK_KP_MULTIPLY:
-				sym = SDLK_ASTERISK;
+				if (gamekey)
+					sym = K_KP_STAR;
+				else	sym = SDLK_ASTERISK;
 				break;
 			case SDLK_KP_MINUS:
-				sym = SDLK_MINUS;
+				if (gamekey)
+					sym = K_KP_MINUS;
+				else	sym = SDLK_MINUS;
 				break;
 			case SDLK_KP_PLUS:
-				sym = SDLK_PLUS;
+				if (gamekey)
+					sym = K_KP_PLUS;
+				else	sym = SDLK_PLUS;
 				break;
 			case SDLK_KP_ENTER:
-				sym = SDLK_RETURN;
+				if (gamekey)
+					sym = K_KP_ENTER;
+				else	sym = SDLK_RETURN;
 				break;
 			case SDLK_KP_EQUALS:
-				sym = SDLK_EQUALS;
+				if (gamekey)
+					sym = 0;
+				else	sym = SDLK_EQUALS;
 				break;
 			case 178: /* the '' key */
 				sym = '~';
 				break;
+			default:
+			/* If we are not directly handled and still above 255,
+			 * just force it to 0. kill unsupported international
+			 * characters, too.  */
+				if ((sym >= SDLK_WORLD_0 && sym <= SDLK_WORLD_95) ||
+									sym > 255)
+					sym = 0;
+				break;
 			}
-			/* If we're not directly handled and still
-			 * above 255, just force it to 0 */
-			if (sym > 255)
-				sym = 0;
 			Key_Event (sym, state);
 			break;
 
