@@ -19,13 +19,11 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
+
 #include "quakedef.h"
+#include "arch_def.h"
 
-/*
-
-key up events are sent even if in console mode
-
-*/
+/* key up events are sent even if in console mode */
 
 #define		HISTORY_FILE_NAME "history.txt"
 #define		CMDLINES 32
@@ -36,10 +34,10 @@ int		key_linepos;
 int		shift_down=false;
 int		key_lastpress;
 int		key_insert;	//johnfitz -- insert key toggle (for editing)
-double	key_blinktime; //johnfitz -- fudge cursor blinking to make it easier to spot in certain cases
+double		key_blinktime; //johnfitz -- fudge cursor blinking to make it easier to spot in certain cases
 
-int		edit_line=0;
-int		history_line=0;
+int		edit_line = 0;
+int		history_line = 0;
 
 keydest_t	key_dest;
 
@@ -52,8 +50,6 @@ qboolean	consolekeys[256];	// if true, can't be rebound while in console
 qboolean	menubound[256];	// if true, can't be rebound while in menu
 qboolean	keydown[256];
 
-qboolean	repeatkeys[256]; //johnfitz -- if true, autorepeat is enabled for this key
-
 typedef struct
 {
 	const char	*name;
@@ -76,25 +72,23 @@ keyname_t keynames[] =
 	{"CTRL", K_CTRL},
 	{"SHIFT", K_SHIFT},
 
-	//johnfitz -- keypad
-	{"KP_NUMLOCK",		KP_NUMLOCK},
-	{"KP_SLASH",		KP_SLASH },
-	{"KP_STAR",			KP_STAR },
-	{"KP_MINUS",		KP_MINUS },
-	{"KP_HOME",			KP_HOME },
-	{"KP_UPARROW",		KP_UPARROW },
-	{"KP_PGUP",			KP_PGUP },
-	{"KP_PLUS",			KP_PLUS },
-	{"KP_LEFTARROW",	KP_LEFTARROW },
-	{"KP_5",			KP_5 },
-	{"KP_RIGHTARROW",	KP_RIGHTARROW },
-	{"KP_END",			KP_END },
-	{"KP_DOWNARROW",	KP_DOWNARROW },
-	{"KP_PGDN",			KP_PGDN },
-	{"KP_ENTER",		KP_ENTER },
-	{"KP_INS",			KP_INS },
-	{"KP_DEL",			KP_DEL },
-	//johnfitz
+//	{"KP_NUMLOCK", K_KP_NUMLOCK},
+	{"KP_SLASH", K_KP_SLASH},
+	{"KP_STAR", K_KP_STAR},
+	{"KP_MINUS", K_KP_MINUS},
+	{"KP_HOME", K_KP_HOME},
+	{"KP_UPARROW", K_KP_UPARROW},
+	{"KP_PGUP", K_KP_PGUP},
+	{"KP_PLUS", K_KP_PLUS},
+	{"KP_LEFTARROW", K_KP_LEFTARROW},
+	{"KP_5", K_KP_5},
+	{"KP_RIGHTARROW", K_KP_RIGHTARROW},
+	{"KP_END", K_KP_END},
+	{"KP_DOWNARROW", K_KP_DOWNARROW},
+	{"KP_PGDN", K_KP_PGDN},
+	{"KP_ENTER", K_KP_ENTER},
+	{"KP_INS", K_KP_INS},
+	{"KP_DEL", K_KP_DEL},
 
 	{"F1", K_F1},
 	{"F2", K_F2},
@@ -116,6 +110,8 @@ keyname_t keynames[] =
 	{"HOME", K_HOME},
 	{"END", K_END},
 
+	{"COMMAND", K_COMMAND},
+
 	{"MOUSE1", K_MOUSE1},
 	{"MOUSE2", K_MOUSE2},
 	{"MOUSE3", K_MOUSE3},
@@ -167,7 +163,7 @@ keyname_t keynames[] =
 
 	{"SEMICOLON", ';'},	// because a raw semicolon seperates commands
 
-	{NULL,0}
+	{NULL,		0}
 };
 
 /*
@@ -178,6 +174,52 @@ keyname_t keynames[] =
 ==============================================================================
 */
 
+static void PasteToConsole (void)
+{
+	char *cbd, *p, *workline;
+	int mvlen, inslen;
+
+	if (key_linepos == MAXCMDLINE - 1)
+		return;
+
+	if ((cbd = PL_GetClipboardData()) == NULL)
+		return;
+
+	p = cbd;
+	while (*p)
+	{
+		if (*p == '\n' || *p == '\r' || *p == '\b')
+		{
+			*p = 0;
+			break;
+		}
+		p++;
+	}
+
+	inslen = (int) (p - cbd);
+	if (inslen + key_linepos > MAXCMDLINE - 1)
+		inslen = MAXCMDLINE - 1 - key_linepos;
+	if (inslen <= 0) goto done;
+
+	workline = key_lines[edit_line];
+	workline += key_linepos;
+	mvlen = (int) strlen(workline);
+	if (mvlen + inslen + key_linepos > MAXCMDLINE - 1)
+	{
+		mvlen = MAXCMDLINE - 1 - key_linepos - inslen;
+		if (mvlen < 0) mvlen = 0;
+	}
+
+	// insert the string
+	if (mvlen != 0)
+		memmove (workline + inslen, workline, mvlen);
+	memcpy (workline, cbd, inslen);
+	key_linepos += inslen;
+	workline[mvlen + inslen] = '\0';
+  done:
+	Z_Free(cbd);
+}
+
 /*
 ====================
 Key_Console -- johnfitz -- heavy revision
@@ -185,24 +227,27 @@ Key_Console -- johnfitz -- heavy revision
 Interactive line editing and console scrollback
 ====================
 */
+extern	char *con_text, key_tabpartial[MAXCMDLINE];
+extern	int con_current, con_linewidth, con_vislines;
+
 void Key_Console (int key)
 {
-	extern	int con_vislines;
-	extern	char key_tabpartial[MAXCMDLINE];
-	static  char current[MAXCMDLINE]="";
+	static	char current[MAXCMDLINE] = "";
+	int	history_line_last;
+	size_t		len;
+	char *workline = key_lines[edit_line];
 
 	switch (key)
 	{
 	case K_ENTER:
-	case KP_ENTER:
 		key_tabpartial[0] = 0;
-		Cbuf_AddText (key_lines[edit_line]+1);	// skip the prompt
+		Cbuf_AddText (workline + 1);	// skip the prompt
 		Cbuf_AddText ("\n");
-		Con_Printf ("%s\n",key_lines[edit_line]);
+		Con_Printf ("%s\n", workline);
 
 		// If the last two lines are identical, skip storing this line in history 
 		// by not incrementing edit_line
-		if (strcmp(key_lines[edit_line],key_lines[(edit_line-1)&31]))
+		if (strcmp(workline, key_lines[(edit_line-1)&31]))
 			edit_line = (edit_line + 1) & 31;
 
 		history_line = edit_line;
@@ -222,51 +267,58 @@ void Key_Console (int key)
 		key_tabpartial[0] = 0;
 		if (key_linepos > 1)
 		{
-			strcpy(key_lines[edit_line] + key_linepos - 1, key_lines[edit_line] + key_linepos);
+			workline += key_linepos - 1;
+			if (workline[1])
+			{
+				len = strlen(workline);
+				memmove (workline, workline + 1, len);
+			}
+			else	*workline = 0;
 			key_linepos--;
 		}
 		return;
 
-	case K_INS:
-		key_insert ^= 1;
-		return;
-
 	case K_DEL:
 		key_tabpartial[0] = 0;
-		if (key_linepos < (int) strlen(key_lines[edit_line]))
-			strcpy(key_lines[edit_line] + key_linepos, key_lines[edit_line] + key_linepos + 1);
+		workline += key_linepos;
+		if (*workline)
+		{
+			if (workline[1])
+			{
+				len = strlen(workline);
+				memmove (workline, workline + 1, len);
+			}
+			else	*workline = 0;
+		}
 		return;
 
 	case K_HOME:
 		if (keydown[K_CTRL])
 		{
 			//skip initial empty lines
-			int		i, x;
-			char	*line;
-			extern int con_current, con_linewidth;
-			extern char *con_text;
+			int i, x;
+			char *line;
 
-			for (i = con_current - con_totallines + 1 ; i <= con_current ; i++)
+			for (i = con_current - con_totallines + 1; i <= con_current; i++)
 			{
-				line = con_text + (i%con_totallines)*con_linewidth;
-				for (x=0 ; x<con_linewidth ; x++)
+				line = con_text + (i % con_totallines) * con_linewidth;
+				for (x = 0; x < con_linewidth; x++)
+				{
 					if (line[x] != ' ')
 						break;
+				}
 				if (x != con_linewidth)
 					break;
 			}
-
 			con_backscroll = CLAMP(0, con_current-i%con_totallines-2, con_totallines-(glheight>>3)-1);
 		}
-		else
-			key_linepos = 1;
+		else	key_linepos = 1;
 		return;
 
 	case K_END:
 		if (keydown[K_CTRL])
 			con_backscroll = 0;
-		else
-			key_linepos = strlen(key_lines[edit_line]);
+		else	key_linepos = strlen(workline);
 		return;
 
 	case K_PGUP:
@@ -294,14 +346,16 @@ void Key_Console (int key)
 		return;
 
 	case K_RIGHTARROW:
-		if ((int) strlen(key_lines[edit_line]) == key_linepos)
+		len = strlen(workline);
+		if ((int)len == key_linepos)
 		{
-			if ((int) strlen(key_lines[(edit_line + 31) & 31]) <= key_linepos)
+			len = strlen(key_lines[(edit_line + 31) & 31]);
+			if ((int)len <= key_linepos)
 				return; // no character to get
-
-			key_lines[edit_line][key_linepos] = key_lines[(edit_line + 31) & 31][key_linepos];
+			workline += key_linepos;
+			*workline = key_lines[(edit_line + 31) & 31][key_linepos];
+			workline[1] = 0;
 			key_linepos++;
-			key_lines[edit_line][key_linepos] = 0;
 		}
 		else
 		{
@@ -311,111 +365,103 @@ void Key_Console (int key)
 		return;
 
 	case K_UPARROW:
-		// Needs rewriting as we have persistent history
+		if (history_line == edit_line)
+			Q_strcpy(current, workline);
+
+		history_line_last = history_line;
+		do
+		{
+			history_line = (history_line - 1) & 31;
+		} while (history_line != edit_line && !key_lines[history_line][1]);
+
+		if (history_line == edit_line)
+		{
+			history_line = history_line_last;
+			return;
+		}
 
-		// if (history_line == 0) return;
-		if (history_line == edit_line) {
-			Q_strcpy(current,key_lines[edit_line]);
-		};
 		key_tabpartial[0] = 0;
-		history_line = (history_line - 1) & 31;
-
-		Q_strcpy(key_lines[edit_line], key_lines[history_line]);
-		key_linepos = Q_strlen(key_lines[edit_line]);
+		Q_strcpy(workline, key_lines[history_line]);
+		key_linepos = Q_strlen(workline);
 		return;
 
 	case K_DOWNARROW:
+		if (history_line == edit_line)
+			return;
+
 		key_tabpartial[0] = 0;
 
-		if (history_line == edit_line) 
-			return;
-
-		history_line = (history_line + 1) & 31;
+		do
+		{
+			history_line = (history_line + 1) & 31;
+		} while (history_line != edit_line && !key_lines[history_line][1]);
 
 		if (history_line == edit_line)
-			Q_strcpy(key_lines[edit_line], current);
-		else
-			Q_strcpy(key_lines[edit_line], key_lines[history_line]);
-		key_linepos = Q_strlen(key_lines[edit_line]);
+			Q_strcpy(workline, current);
+		else	Q_strcpy(workline, key_lines[history_line]);
+		key_linepos = Q_strlen(workline);
 		return;
 
-	case 'c':
-		if (keydown[K_CTRL]) {
-			// Control+C (S.A)
-			//   abort this line.
-			Con_Printf ("%s\n",key_lines[edit_line]);
-			key_lines[edit_line][0] = ']';
-			key_lines[edit_line][1] = 0; //johnfitz -- otherwise old history items show up in the new edit line
-			key_linepos = 1;
-			history_line=edit_line;
+	case K_INS:
+		if (keydown[K_SHIFT])		/* Shift-Ins paste */
+			PasteToConsole();
+		else	key_insert ^= 1;
+		return;
+
+	case 'v':
+	case 'V':
+#if defined(__MACOSX__) || defined(__MACOS__)
+		if (keydown[K_COMMAND]) {	/* Cmd+v paste (Mac-only) */
+			PasteToConsole();
 			return;
 		}
-	}
-
-//johnfitz -- clipboard pasting, stolen from zquake
-/* TODO: make portable or remove
-	if ((key=='V' || key=='v') && keydown[K_CTRL])
-	{
-		HANDLE	th;
-		char	*clipText;
-		int		i;
-
-		if (OpenClipboard(NULL)) {
-			th = GetClipboardData(CF_TEXT);
-			if (th) {
-				clipText = GlobalLock(th);
-				if (clipText) {
-					for (i=0; clipText[i]; i++)
-						if (clipText[i]=='\n' || clipText[i]=='\r' || clipText[i]=='\b')
-							break;
-					if (i + strlen(key_lines[edit_line]) > MAXCMDLINE-1)
-						i = MAXCMDLINE-1 - strlen(key_lines[edit_line]);
-					if (i > 0)
-					{	// insert the string
-						memmove (key_lines[edit_line] + key_linepos + i,
-							key_lines[edit_line] + key_linepos, strlen(key_lines[edit_line]) - key_linepos + 1);
-						memcpy (key_lines[edit_line] + key_linepos, clipText, i);
-						key_linepos += i;
-					}
-				}
-				GlobalUnlock(th);
-			}
-			CloseClipboard();
+#endif
+		if (keydown[K_CTRL]) {		/* Ctrl+v paste */
+			PasteToConsole();
+			return;
 		}
-		return;
+		break;
+
+	case 'c':
+	case 'C':
+		if (keydown[K_CTRL]) {		/* Ctrl+C: abort the line -- S.A */
+			Con_Printf ("%s\n", workline);
+			workline[0] = ']';
+			workline[1] = 0;
+			key_linepos = 1;
+			history_line= edit_line;
+			return;
+		}
+		break;
 	}
-*/
+
 	if (key < 32 || key > 127)
 		return;	// non printable
 
-	//johnfitz -- stolen from darkplaces
 	if (key_linepos < MAXCMDLINE-1)
 	{
-		int i;
+		qboolean endpos = !workline[key_linepos];
 
 		key_tabpartial[0] = 0; //johnfitz
-
-		if (key_insert)	// check insert mode
+		// if inserting, move the text to the right
+		if (key_insert && !endpos)
 		{
-			// can't do strcpy to move string to right
-			i = strlen(key_lines[edit_line]) - 1;
-
-			if (i == 254)
-				i--;
-
-			for (; i >= key_linepos; i--)
-				key_lines[edit_line][i + 1] = key_lines[edit_line][i];
+			workline[MAXCMDLINE - 2] = 0;
+			workline += key_linepos;
+			len = strlen(workline) + 1;
+			memmove (workline + 1, workline, len);
+			*workline = key;
+		}
+		else
+		{
+			workline += key_linepos;
+			*workline = key;
+			// null terminate if at the end
+			if (endpos)
+				workline[1] = 0;
 		}
-
-		// only null terminate if at the end
-		i = key_lines[edit_line][key_linepos];
-		key_lines[edit_line][key_linepos] = key;
 		key_linepos++;
-
-		if (!i)
-			key_lines[edit_line][key_linepos] = 0;
 	}
-	//johnfitz
 }
 
 //============================================================================
@@ -510,8 +556,8 @@ FIXME: handle quote special (general escape sequence?)
 */
 const char *Key_KeynumToString (int keynum)
 {
-	keyname_t	*kn;
 	static	char	tinystr[2];
+	keyname_t	*kn;
 
 	if (keynum == -1)
 		return "<KEY NOT FOUND>";
@@ -522,9 +568,11 @@ const char *Key_KeynumToString (int keynum)
 		return tinystr;
 	}
 
-	for (kn=keynames ; kn->name ; kn++)
+	for (kn = keynames; kn->name; kn++)
+	{
 		if (keynum == kn->keynum)
 			return kn->name;
+	}
 
 	return "<UNKNOWN KEYNUM>";
 }
@@ -537,9 +585,6 @@ Key_SetBinding
 */
 void Key_SetBinding (int keynum, const char *binding)
 {
-	char	*new_binding;
-	int		l;
-
 	if (keynum == -1)
 		return;
 
@@ -551,11 +596,7 @@ void Key_SetBinding (int keynum, const char *binding)
 	}
 
 // allocate memory for new binding
-	l = Q_strlen (binding);
-	new_binding = (char *) Z_Malloc (l+1);
-	Q_strcpy (new_binding, binding);
-	new_binding[l] = 0;
-	keybindings[keynum] = new_binding;
+	keybindings[keynum] = Z_Strdup(binding);
 }
 
 /*
@@ -565,7 +606,7 @@ Key_Unbind_f
 */
 void Key_Unbind_f (void)
 {
-	int		b;
+	int	b;
 
 	if (Cmd_Argc() != 2)
 	{
@@ -574,7 +615,7 @@ void Key_Unbind_f (void)
 	}
 
 	b = Key_StringToKeynum (Cmd_Argv(1));
-	if (b==-1)
+	if (b == -1)
 	{
 		Con_Printf ("\"%s\" isn't a valid key\n", Cmd_Argv(1));
 		return;
@@ -585,11 +626,13 @@ void Key_Unbind_f (void)
 
 void Key_Unbindall_f (void)
 {
-	int		i;
+	int	i;
 
-	for (i=0 ; i<256 ; i++)
+	for (i = 0; i < 256; i++)
+	{
 		if (keybindings[i])
 			Key_SetBinding (i, "");
+	}
 }
 
 /*
@@ -599,16 +642,17 @@ Key_Bindlist_f -- johnfitz
 */
 void Key_Bindlist_f (void)
 {
-	int		i, count;
+	int	i, count;
 
 	count = 0;
-	for (i=0 ; i<256 ; i++)
-		if (keybindings[i])
-			if (*keybindings[i])
-			{
-				Con_SafePrintf ("   %s \"%s\"\n", Key_KeynumToString(i), keybindings[i]);
-				count++;
-			}
+	for (i = 0; i < 256; i++)
+	{
+		if (keybindings[i] && *keybindings[i])
+		{
+			Con_SafePrintf ("   %s \"%s\"\n", Key_KeynumToString(i), keybindings[i]);
+			count++;
+		}
+	}
 	Con_SafePrintf ("%i bindings\n", count);
 }
 
@@ -619,8 +663,8 @@ Key_Bind_f
 */
 void Key_Bind_f (void)
 {
-	int			i, c, b;
-	char		cmd[1024];
+	int	i, c, b;
+	char	cmd[1024];
 
 	c = Cmd_Argc();
 
@@ -630,7 +674,7 @@ void Key_Bind_f (void)
 		return;
 	}
 	b = Key_StringToKeynum (Cmd_Argv(1));
-	if (b==-1)
+	if (b == -1)
 	{
 		Con_Printf ("\"%s\" isn't a valid key\n", Cmd_Argv(1));
 		return;
@@ -646,8 +690,8 @@ void Key_Bind_f (void)
 	}
 
 // copy the rest of the command line
-	cmd[0] = 0;		// start out with a null string
-	for (i=2 ; i< c ; i++)
+	cmd[0] = 0;
+	for (i = 2; i < c; i++)
 	{
 		q_strlcat (cmd, Cmd_Argv(i), sizeof(cmd));
 		if (i != (c-1))
@@ -666,12 +710,13 @@ Writes lines containing "bind key value"
 */
 void Key_WriteBindings (FILE *f)
 {
-	int		i;
+	int	i;
 
-	for (i=0 ; i<256 ; i++)
-		if (keybindings[i])
-			if (*keybindings[i])
-				fprintf (f, "bind \"%s\" \"%s\"\n", Key_KeynumToString(i), keybindings[i]);
+	for (i = 0; i < 256; i++)
+	{
+		if (keybindings[i] && *keybindings[i])
+			fprintf (f, "bind \"%s\" \"%s\"\n", Key_KeynumToString(i), keybindings[i]);
+	}
 }
 
 
@@ -749,7 +794,7 @@ Key_Init
 */
 void Key_Init (void)
 {
-	int		i;
+	int	i;
 
 	History_Init ();
 #if 0 /* This section of code is now done in History_Init */
@@ -766,10 +811,9 @@ void Key_Init (void)
 //
 // init ascii characters in console mode
 //
-	for (i=32 ; i<128 ; i++)
+	for (i = 32; i < 128; i++)
 		consolekeys[i] = true;
 	consolekeys[K_ENTER] = true;
-	consolekeys[KP_ENTER] = true; //johnfitz
 	consolekeys[K_TAB] = true;
 	consolekeys[K_LEFTARROW] = true;
 	consolekeys[K_RIGHTARROW] = true;
@@ -788,21 +832,9 @@ void Key_Init (void)
 	consolekeys['`'] = false;
 	consolekeys['~'] = false;
 
-	//johnfitz -- repeating keys
-	for (i=0 ; i<256 ; i++)
-		repeatkeys[i] = false;
-	repeatkeys[K_BACKSPACE] = true;
-	repeatkeys[K_DEL] = true;
-	repeatkeys[K_PAUSE] = true;
-	repeatkeys[K_PGUP] = true;
-	repeatkeys[K_PGDN] = true;
-	repeatkeys[K_LEFTARROW] = true;
-	repeatkeys[K_RIGHTARROW] = true;
-	//johnfitz
-
-	for (i=0 ; i<256 ; i++)
+	for (i = 0; i < 256; i++)
 		keyshift[i] = i;
-	for (i='a' ; i<='z' ; i++)
+	for (i = 'a' ; i <= 'z'; i++)
 		keyshift[i] = i - 'a' + 'A';
 	keyshift['1'] = '!';
 	keyshift['2'] = '@';
@@ -827,7 +859,7 @@ void Key_Init (void)
 	keyshift['\\'] = '|';
 
 	menubound[K_ESCAPE] = true;
-	for (i=0 ; i<12 ; i++)
+	for (i = 0; i < 12; i++)
 		menubound[K_F1+i] = true;
 
 //
@@ -860,9 +892,7 @@ void Key_Event (int key, qboolean down)
 	key_lastpress = key;
 	key_count++;
 	if (key_count <= 0)
-	{
 		return;		// just catching keys for Con_NotifyBox
-	}
 
 // update auto-repeat status
 	if (down)
@@ -870,26 +900,17 @@ void Key_Event (int key, qboolean down)
 		key_repeats[key]++;
 		if (key_repeats[key] > 1)
 		{
-			if (key_dest == key_console)
-				goto autorep0;
-			if (key_dest == key_message)
-				goto autorep0;
-			if (!repeatkeys[key]) //johnfitz -- use repeatkeys[]
-				return;	// ignore most autorepeats
+			if (key_dest == key_game && !con_forcedup)
+				return;	// ignore autorepeats in game mode
 		}
-
-		if (key >= 200 && !keybindings[key])
-			Con_Printf ("%s is unbound, hit F4 to set.\n", Key_KeynumToString (key) );
+		else if (key >= 200 && !keybindings[key])
+			Con_Printf ("%s is unbound, hit F4 to set.\n", Key_KeynumToString(key));
 	}
 
-autorep0:
-
 	if (key == K_SHIFT)
 		shift_down = down;
 
-//
 // handle escape specialy, so the user can never unbind it
-//
 	if (key == K_ESCAPE)
 	{
 		if (!down)
@@ -912,20 +933,11 @@ autorep0:
 		return;
 	}
 
-// johnfitz -- alt-enter to toggle fullscreen. FIXME -- this does NOT work
-// But this hack (from sf.net/uhexen2) for SDLFitz works for me. S.A
-// *** moved to main.c so that it works properly ***
-//	if (!down && (key == K_ENTER) && keydown[K_ALT])
-//		VID_Toggle();
-// johnfitz
-
-//
 // key up events only generate commands if the game key binding is
 // a button command (leading + sign).  These will occur even in console mode,
 // to keep the character from continuing an action started before a console
 // switch.  Button commands include the kenum as a parameter, so multiple
 // downs can be matched with ups
-//
 	if (!down)
 	{
 		kb = keybindings[key];
@@ -946,21 +958,17 @@ autorep0:
 		return;
 	}
 
-//
 // during demo playback, most keys bring up the main menu
-//
 	if (cls.demoplayback && down && consolekeys[key] && key_dest == key_game && key != K_TAB)
 	{
 		M_ToggleMenu_f ();
 		return;
 	}
 
-//
 // if not a consolekey, send to the interpreter no matter what mode is
-//
-	if ( (key_dest == key_menu && menubound[key])
-	|| (key_dest == key_console && !consolekeys[key])
-	|| (key_dest == key_game && ( !con_forcedup || !consolekeys[key] ) ) )
+	if ((key_dest == key_menu && menubound[key]) ||
+	    (key_dest == key_console && !consolekeys[key]) ||
+	    (key_dest == key_game && (!con_forcedup || !consolekeys[key])))
 	{
 		kb = keybindings[key];
 		if (kb)
@@ -983,9 +991,7 @@ autorep0:
 		return;		// other systems only care about key down events
 
 	if (shift_down)
-	{
 		key = keyshift[key];
-	}
 
 	switch (key_dest)
 	{
@@ -1013,12 +1019,12 @@ Key_ClearStates
 */
 void Key_ClearStates (void)
 {
-	int		i;
+	int	i;
 
-	for (i=0 ; i<256 ; i++)
+	for (i = 0; i < 256; i++)
 	{
-		keydown[i] = false;
-		key_repeats[i] = 0;
+		if (keydown[i])
+			Key_Event (i, false);
 	}
 }
 
