@@ -19,11 +19,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include "q_stdinc.h"
-#include "arch_def.h"
-#include "net_sys.h"	/* FIXME */
 #include "quakedef.h"
-#include "net_defs.h"	/* FIXME */
 #include "bgmusic.h"
 
 void (*vid_menucmdfn)(void); //johnfitz
@@ -222,7 +218,7 @@ void M_ToggleMenu_f (void)
 		}
 
 		IN_Activate();
-		key_dest = (cls.state == ca_connected) ? key_game : key_console;
+		key_dest = key_game;
 		m_state = m_none;
 		return;
 	}
@@ -280,7 +276,7 @@ void M_Main_Key (int key)
 	{
 	case K_ESCAPE:
 		IN_Activate();
-		key_dest = (cls.state == ca_connected) ? key_game : key_console;
+		key_dest = key_game;
 		m_state = m_none;
 		cls.demonum = m_save_demonum;
 		if (!fitzmode)	/* QuakeSpasm customization: */
@@ -985,21 +981,20 @@ void M_Menu_Options_f (void)
 
 void M_AdjustSliders (int dir)
 {
-	float	f;
+	float	f, l;
 
 	S_LocalSound ("misc/menu3.wav");
 
 	switch (options_cursor)
 	{
 	case OPT_SCALE:	// console and menu scale
-		f = scr_scale.value + dir * .1; // or .2
+		l = ((vid.width + 31) / 32) / 10.0;
+		f = scr_conscale.value + dir * .1;
 		if (f < 1)	f = 1;
-		else if (f > 6)	f = 6;
-		Cvar_SetValue ("scr_scale", f);
-		// status bar size increases half as fast
-		Cvar_SetValue ("scr_sbarscale", (scr_scale.value - 1)/2 + 1);
-		Cvar_SetValue ("scr_conscale", scr_scale.value);
-		Cvar_SetValue ("scr_menuscale", scr_scale.value);
+		else if(f > l)	f = l;
+		Cvar_SetValue ("scr_conscale", f);
+		Cvar_SetValue ("scr_menuscale", f);
+		Cvar_SetValue ("scr_sbarscale", f);
 		break;
 	case OPT_SCRSIZE:	// screen size
 		f = scr_viewsize.value + dir * 10;
@@ -1107,7 +1102,7 @@ void M_DrawCheckbox (int x, int y, int on)
 
 void M_Options_Draw (void)
 {
-	float		r;
+	float		r, l;
 	qpic_t	*p;
 
 	M_DrawTransPic (16, 4, Draw_CachePic ("gfx/qplaque.lmp") );
@@ -1124,7 +1119,8 @@ void M_Options_Draw (void)
 
 	// OPT_SCALE:
 	M_Print (16, 32 + 8*OPT_SCALE,		"                 Scale");
-	r = (scr_scale.value-1)/5 ; // r ranges from 0 to 1, scr_scale from 1 to 6
+	l = (vid.width / 320.0) - 1;
+	r = l > 0 ? (scr_conscale.value - 1) / l : 0;
 	M_DrawSlider (220, 32 + 8*OPT_SCALE, r);
 
 	// OPT_SCRSIZE:
@@ -1286,8 +1282,11 @@ const char *bindnames[][2] =
 
 #define	NUMCOMMANDS	(sizeof(bindnames)/sizeof(bindnames[0]))
 
-int		keys_cursor;
-int		bind_grab;
+#define KEYS_SIZE 18
+
+static int	keys_cursor;
+qboolean	m_keys_bind_grab;
+static int	keys_top;
 
 void M_Menu_Keys_f (void)
 {
@@ -1342,6 +1341,7 @@ void M_UnbindCommand (const char *command)
 	}
 }
 
+extern qpic_t	*pic_up, *pic_down;
 
 void M_Keys_Draw (void)
 {
@@ -1353,19 +1353,27 @@ void M_Keys_Draw (void)
 	p = Draw_CachePic ("gfx/ttl_cstm.lmp");
 	M_DrawPic ( (320-p->width)/2, 4, p);
 
-	if (bind_grab)
+	if (m_keys_bind_grab)
 		M_Print (12, 32, "Press a key or button for this action");
 	else
 		M_Print (18, 32, "Enter to change, backspace to clear");
 
+	if (keys_top)
+		M_DrawTransPic (6, 48, pic_up);
+	if (keys_top + KEYS_SIZE < (int)NUMCOMMANDS)
+		M_DrawTransPic (6, 48 + ((KEYS_SIZE-1)*8), pic_down);
+
 // search for known bindings
-	for (i = 0; i < (int)NUMCOMMANDS; i++)
+	for (i = 0; i < KEYS_SIZE; i++)
 	{
+		if (i+keys_top >= (int)NUMCOMMANDS)
+			break;
+
 		y = 48 + 8*i;
 
-		M_Print (16, y, bindnames[i][1]);
+		M_Print (16, y, bindnames[i+keys_top][1]);
 
-		M_FindKeysForCommand (bindnames[i][0], keys);
+		M_FindKeysForCommand (bindnames[i+keys_top][0], keys);
 
 		if (keys[0] == -1)
 		{
@@ -1384,10 +1392,10 @@ void M_Keys_Draw (void)
 		}
 	}
 
-	if (bind_grab)
-		M_DrawCharacter (130, 48 + keys_cursor*8, '=');
+	if (m_keys_bind_grab)
+		M_DrawCharacter (130, 48 + (keys_cursor-keys_top)*8, '=');
 	else
-		M_DrawCharacter (130, 48 + keys_cursor*8, 12+((int)(realtime*4)&1));
+		M_DrawCharacter (130, 48 + (keys_cursor-keys_top)*8, 12+((int)(realtime*4)&1));
 }
 
 
@@ -1396,7 +1404,7 @@ void M_Keys_Key (int k)
 	char	cmd[80];
 	int		keys[2];
 
-	if (bind_grab)
+	if (m_keys_bind_grab)
 	{	// defining a key
 		S_LocalSound ("misc/menu1.wav");
 		if ((k != K_ESCAPE) && (k != '`'))
@@ -1405,7 +1413,7 @@ void M_Keys_Key (int k)
 			Cbuf_InsertText (cmd);
 		}
 
-		bind_grab = false;
+		m_keys_bind_grab = false;
 		IN_Deactivate(vid.type == MODE_WINDOWED); // deactivate because we're returning to the menu
 		return;
 	}
@@ -1437,7 +1445,7 @@ void M_Keys_Key (int k)
 		S_LocalSound ("misc/menu2.wav");
 		if (keys[1] != -1)
 			M_UnbindCommand (bindnames[keys_cursor][0]);
-		bind_grab = true;
+		m_keys_bind_grab = true;
 		IN_Activate(); // activate to allow mouse key binding
 		break;
 
@@ -1447,6 +1455,11 @@ void M_Keys_Key (int k)
 		M_UnbindCommand (bindnames[keys_cursor][0]);
 		break;
 	}
+
+	if (keys_cursor < keys_top)
+		keys_top = keys_cursor;
+	else if (keys_cursor >= keys_top+KEYS_SIZE)
+		keys_top = keys_cursor - KEYS_SIZE + 1;
 }
 
 //=============================================================================
@@ -2341,42 +2354,19 @@ void M_Menu_ServerList_f (void)
 
 void M_ServerList_Draw (void)
 {
-	int		n;
-	char	string [64];
+	int	n;
 	qpic_t	*p;
 
 	if (!slist_sorted)
 	{
-		if (hostCacheCount > 1)
-		{
-			int	i,j;
-			hostcache_t temp;
-			for (i = 0; i < hostCacheCount; i++)
-			{
-				for (j = i + 1; j < hostCacheCount; j++)
-				{
-					if (strcmp(hostcache[j].name, hostcache[i].name) < 0)
-					{
-						Q_memcpy(&temp, &hostcache[j], sizeof(hostcache_t));
-						Q_memcpy(&hostcache[j], &hostcache[i], sizeof(hostcache_t));
-						Q_memcpy(&hostcache[i], &temp, sizeof(hostcache_t));
-					}
-				}
-			}
-		}
 		slist_sorted = true;
+		NET_SlistSort ();
 	}
 
 	p = Draw_CachePic ("gfx/p_multi.lmp");
 	M_DrawPic ( (320-p->width)/2, 4, p);
 	for (n = 0; n < hostCacheCount; n++)
-	{
-		if (hostcache[n].maxusers)
-			sprintf(string, "%-15.15s %-15.15s %2u/%2u\n", hostcache[n].name, hostcache[n].map, hostcache[n].users, hostcache[n].maxusers);
-		else
-			sprintf(string, "%-15.15s %-15.15s\n", hostcache[n].name, hostcache[n].map);
-		M_Print (16, 32 + 8*n, string);
-	}
+		M_Print (16, 32 + 8*n, NET_SlistPrintServer (n));
 	M_DrawCharacter (0, 32 + slist_cursor*8, 12+((int)(realtime*4)&1));
 
 	if (*m_return_reason)
@@ -2420,7 +2410,7 @@ void M_ServerList_Key (int k)
 		IN_Activate();
 		key_dest = key_game;
 		m_state = m_none;
-		Cbuf_AddText ( va ("connect \"%s\"\n", hostcache[slist_cursor].cname) );
+		Cbuf_AddText ( va ("connect \"%s\"\n", NET_SlistPrintServerName(slist_cursor)) );
 		break;
 
 	default:
