@@ -46,20 +46,19 @@ static int receivedDuplicateCount = 0;
 static int shortPacketCount = 0;
 static int droppedDatagrams;
 
-static int myDriverLevel;
-
 static struct
 {
 	unsigned int	length;
 	unsigned int	sequence;
-	byte			data[MAX_DATAGRAM];
+	byte	data[MAX_DATAGRAM];
 } packetBuffer;
 
+static int myDriverLevel;
+
 extern qboolean m_return_onerror;
 extern char m_return_reason[32];
 
 
-//#ifdef DEBUG
 static char *StrAddr (struct qsockaddr *addr)
 {
 	static char buf[34];
@@ -70,7 +69,6 @@ static char *StrAddr (struct qsockaddr *addr)
 		sprintf (buf + n * 2, "%02x", *p++);
 	return buf;
 }
-//#endif
 
 
 #ifdef BAN_TEST
@@ -82,7 +80,8 @@ static void NET_Ban_f (void)
 {
 	char	addrStr [32];
 	char	maskStr [32];
-	void	(*print_fn) (const char *fmt, ...) __fp_attribute__((__format__(__printf__,1,2)));
+	void	(*print_fn)(const char *fmt, ...)
+				__fp_attribute__((__format__(__printf__,1,2)));
 
 	if (cmd_source == src_command)
 	{
@@ -95,7 +94,7 @@ static void NET_Ban_f (void)
 	}
 	else
 	{
-		if (pr_global_struct->deathmatch && !host_client->privileged)
+		if (pr_global_struct->deathmatch)
 			return;
 		print_fn = SV_ClientPrintf;
 	}
@@ -303,15 +302,16 @@ int	Datagram_GetMessage (qsocket_t *sock)
 
 	while (1)
 	{
-		length = sfunc.Read (sock->socket, (byte *)&packetBuffer, NET_DATAGRAMSIZE, &readaddr);
+		length = (unsigned int) sfunc.Read(sock->socket, (byte *)&packetBuffer,
+							NET_DATAGRAMSIZE, &readaddr);
 
-//	if ((rand() & 255) > 220)
-//		continue;
+	//	if ((rand() & 255) > 220)
+	//		continue;
 
 		if (length == 0)
 			break;
 
-		if (length == -1)
+		if (length == (unsigned int)-1)
 		{
 			Con_Printf("Read error\n");
 			return -1;
@@ -319,11 +319,9 @@ int	Datagram_GetMessage (qsocket_t *sock)
 
 		if (sfunc.AddrCompare(&readaddr, &sock->addr) != 0)
 		{
-#ifdef DEBUG
 			Con_Printf("Forged packet received\n");
 			Con_Printf("Expected: %s\n", StrAddr (&sock->addr));
 			Con_Printf("Received: %s\n", StrAddr (&readaddr));
-#endif
 			continue;
 		}
 
@@ -506,7 +504,7 @@ static const char *Strip_Port (const char *host)
 
 	if (!host || !*host)
 		return host;
-	strcpy (noport, host);
+	q_strlcpy (noport, host, sizeof(noport));
 	if ((p = Q_strrchr(noport, ':')) == NULL)
 		return host;
 	*p++ = '\0';
@@ -519,10 +517,11 @@ static const char *Strip_Port (const char *host)
 	return noport;
 }
 
+
 static qboolean testInProgress = false;
 static int		testPollCount;
 static int		testDriver;
-static int		testSocket;
+static sys_socket_t	testSocket;
 
 static void Test_Poll (void *);
 static PollProcedure	testPollProcedure = {NULL, 0.0, Test_Poll};
@@ -537,14 +536,13 @@ static void Test_Poll (void *unused)
 	int		colors;
 	int		frags;
 	int		connectTime;
-	byte	playerNumber;
 
 	net_landriverlevel = testDriver;
 
 	while (1)
 	{
 		len = dfunc.Read (testSocket, net_message.data, net_message.maxsize, &clientaddr);
-		if (len < sizeof(int))
+		if (len < (int) sizeof(int))
 			break;
 
 		net_message.cursize = len;
@@ -554,7 +552,7 @@ static void Test_Poll (void *unused)
 		MSG_ReadLong();
 		if (control == -1)
 			break;
-		if ((control & (~NETFLAG_LENGTH_MASK)) !=  NETFLAG_CTL)
+		if ((control & (~NETFLAG_LENGTH_MASK)) != (int)NETFLAG_CTL)
 			break;
 		if ((control & NETFLAG_LENGTH_MASK) != len)
 			break;
@@ -562,14 +560,14 @@ static void Test_Poll (void *unused)
 		if (MSG_ReadByte() != CCREP_PLAYER_INFO)
 			Sys_Error("Unexpected repsonse to Player Info request\n");
 
-		playerNumber = MSG_ReadByte();
+		MSG_ReadByte(); /* playerNumber */
 		Q_strcpy(name, MSG_ReadString());
 		colors = MSG_ReadLong();
 		frags = MSG_ReadLong();
 		connectTime = MSG_ReadLong();
 		Q_strcpy(address, MSG_ReadString());
 
-		Con_Printf("%s\n  frags:%3i  colors:%u %u  time:%u\n  %s\n", name, frags, colors >> 4, colors & 0x0f, connectTime / 60, address);
+		Con_Printf("%s\n  frags:%3i  colors:%d %d  time:%d\n  %s\n", name, frags, colors >> 4, colors & 0x0f, connectTime / 60, address);
 	}
 
 	testPollCount--;
@@ -632,7 +630,7 @@ static void Test_f (void)
 
 JustDoIt:
 	testSocket = dfunc.Open_Socket(0);
-	if (testSocket == -1)
+	if (testSocket == INVALID_SOCKET)
 		return;
 
 	testInProgress = true;
@@ -656,7 +654,7 @@ JustDoIt:
 
 static qboolean test2InProgress = false;
 static int		test2Driver;
-static int		test2Socket;
+static sys_socket_t	test2Socket;
 
 static void Test2_Poll (void *);
 static PollProcedure	test2PollProcedure = {NULL, 0.0, Test2_Poll};
@@ -673,7 +671,7 @@ static void Test2_Poll (void *unused)
 	name[0] = 0;
 
 	len = dfunc.Read (test2Socket, net_message.data, net_message.maxsize, &clientaddr);
-	if (len < sizeof(int))
+	if (len < (int) sizeof(int))
 		goto Reschedule;
 
 	net_message.cursize = len;
@@ -683,7 +681,7 @@ static void Test2_Poll (void *unused)
 	MSG_ReadLong();
 	if (control == -1)
 		goto Error;
-	if ((control & (~NETFLAG_LENGTH_MASK)) !=  NETFLAG_CTL)
+	if ((control & (~NETFLAG_LENGTH_MASK)) != (int)NETFLAG_CTL)
 		goto Error;
 	if ((control & NETFLAG_LENGTH_MASK) != len)
 		goto Error;
@@ -766,7 +764,7 @@ static void Test2_f (void)
 
 JustDoIt:
 	test2Socket = dfunc.Open_Socket(0);
-	if (test2Socket == -1)
+	if (test2Socket == INVALID_SOCKET)
 		return;
 
 	test2InProgress = true;
@@ -794,6 +792,7 @@ int Datagram_Init (void)
 	banMask.s_addr = INADDR_NONE;
 #endif
 	myDriverLevel = net_driverlevel;
+
 	Cmd_AddCommand ("net_stats", NET_Stats_f);
 
 	if (safemode || COM_CheckParm("-nolan"))
@@ -879,7 +878,7 @@ static qsocket_t *_Datagram_CheckNewConnections (void)
 	SZ_Clear(&net_message);
 
 	len = dfunc.Read (acceptsock, net_message.data, net_message.maxsize, &clientaddr);
-	if (len < sizeof(int))
+	if (len < (int) sizeof(int))
 		return NULL;
 	net_message.cursize = len;
 
@@ -888,7 +887,7 @@ static qsocket_t *_Datagram_CheckNewConnections (void)
 	MSG_ReadLong();
 	if (control == -1)
 		return NULL;
-	if ((control & (~NETFLAG_LENGTH_MASK)) !=  NETFLAG_CTL)
+	if ((control & (~NETFLAG_LENGTH_MASK)) != (int)NETFLAG_CTL)
 		return NULL;
 	if ((control & NETFLAG_LENGTH_MASK) != len)
 		return NULL;
@@ -959,27 +958,11 @@ static qsocket_t *_Datagram_CheckNewConnections (void)
 	if (command == CCREQ_RULE_INFO)
 	{
 		const char	*prevCvarName;
-		cvar_t	*var;
+		cvar_t			*var;
 
 		// find the search start location
 		prevCvarName = MSG_ReadString();
-		if (*prevCvarName)
-		{
-			var = Cvar_FindVar (prevCvarName);
-			if (!var)
-				return NULL;
-			var = var->next;
-		}
-		else
-			var = cvar_vars;
-
-		// search for the next server cvar
-		while (var)
-		{
-			if (var->server)
-				break;
-			var = var->next;
-		}
+		var = Cvar_FindVarAfter (prevCvarName, CVAR_SERVERINFO);
 
 		// send the response
 		SZ_Clear(&net_message);
@@ -1162,7 +1145,7 @@ static void _Datagram_SearchForHosts (qboolean xmit)
 
 	while ((ret = dfunc.Read (dfunc.controlSock, net_message.data, net_message.maxsize, &readaddr)) > 0)
 	{
-		if (ret < sizeof(int))
+		if (ret < (int) sizeof(int))
 			continue;
 		net_message.cursize = ret;
 
@@ -1179,7 +1162,7 @@ static void _Datagram_SearchForHosts (qboolean xmit)
 		MSG_ReadLong();
 		if (control == -1)
 			continue;
-		if ((control & (~NETFLAG_LENGTH_MASK)) !=  NETFLAG_CTL)
+		if ((control & (~NETFLAG_LENGTH_MASK)) != (int)NETFLAG_CTL)
 			continue;
 		if ((control & NETFLAG_LENGTH_MASK) != ret)
 			continue;
@@ -1309,17 +1292,15 @@ static qsocket_t *_Datagram_Connect (const char *host)
 				// is it from the right place?
 				if (sfunc.AddrCompare(&readaddr, &sendaddr) != 0)
 				{
-//#ifdef DEBUG
 					Con_Printf("wrong reply address\n");
 					Con_Printf("Expected: %s | %s\n", dfunc.AddrToString (&sendaddr), StrAddr(&sendaddr));
 					Con_Printf("Received: %s | %s\n", dfunc.AddrToString (&readaddr), StrAddr(&readaddr));
 					SCR_UpdateScreen ();
-//#endif
 					ret = 0;
 					continue;
 				}
 
-				if (ret < sizeof(int))
+				if (ret < (int) sizeof(int))
 				{
 					ret = 0;
 					continue;
@@ -1335,7 +1316,7 @@ static qsocket_t *_Datagram_Connect (const char *host)
 					ret = 0;
 					continue;
 				}
-				if ((control & (~NETFLAG_LENGTH_MASK)) !=  NETFLAG_CTL)
+				if ((control & (~NETFLAG_LENGTH_MASK)) != (int)NETFLAG_CTL)
 				{
 					ret = 0;
 					continue;
@@ -1378,8 +1359,7 @@ static qsocket_t *_Datagram_Connect (const char *host)
 	{
 		reason = MSG_ReadString();
 		Con_Printf("%s\n", reason);
-		Q_strncpy(m_return_reason, reason, 31);
-		m_return_reason[31] = 0;
+		q_strlcpy(m_return_reason, reason, sizeof(m_return_reason));
 		goto ErrorReturn;
 	}
 
@@ -1419,6 +1399,7 @@ ErrorReturn2:
 	dfunc.Close_Socket(newsock);
 	if (m_return_onerror)
 	{
+		IN_Deactivate(vid.type == MODE_WINDOWED);
 		key_dest = key_menu;
 		m_state = m_return_state;
 		m_return_onerror = false;
