@@ -23,10 +23,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef __QUAKEDEFS_H
 #define __QUAKEDEFS_H
 
-// numeric macro to string conversion
-#define STR_(x) #x
-#define STR(x) STR_(x)
-
 // quakedef.h -- primary header for client
 
 #define	QUAKE_GAME			// as opposed to utilities
@@ -39,8 +35,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define	X11_VERSION		1.10
 
 #define	FITZQUAKE_VERSION	0.85	//johnfitz
-#define	QUAKESPASM_VERSION	0.7
-#define	QUAKESPASM_VER_PATCH	7	// helper to print a string like 0.85.7
+#define	QUAKESPASM_VERSION	0.8
+#define	QUAKESPASM_VER_PATCH	8	// helper to print a string like 0.85.8
 
 //define	PARANOID			// speed sapping error checking
 
@@ -87,8 +83,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define	MIN_EDICTS		256			// johnfitz -- lowest allowed value for max_edicts cvar
 #define	MAX_EDICTS		32000		// johnfitz -- highest allowed value for max_edicts cvar
 									// ents past 8192 can't play sounds in the standard protocol
-#define	DEF_EDICTS		2048
-
 #define	MAX_LIGHTSTYLES	64
 #define	MAX_MODELS		2048		// johnfitz -- was 256
 #define	MAX_SOUNDS		2048		// johnfitz -- was 256
@@ -219,8 +213,13 @@ typedef struct
 #include "server.h"
 
 #include "platform.h"
+#if defined(SDL_FRAMEWORK) || defined(NO_SDL_CONFIG)
+#include <SDL/SDL.h>
+#include <SDL/SDL_opengl.h>
+#else
 #include "SDL.h"
 #include "SDL_opengl.h"
+#endif
 
 #include "console.h"
 #include "wad.h"
