@@ -25,6 +25,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 extern cvar_t gl_fullbrights, r_drawflat, gl_overbright, r_oldwater; //johnfitz
 
+extern cvar_t gl_zfix; // QuakeSpasm z-fighting fix
+
 int		gl_lightmap_format;
 int		lightmap_bytes;
 
@@ -154,7 +156,7 @@ void R_DrawSequentialPoly (msurface_t *s)
 		{
 			for (p = s->polys->next; p; p = p->next)
 			{
-				srand((unsigned int) (size_t) p);
+				srand((unsigned int) (uintptr_t) p);
 				glColor3f (rand()%256/255.0, rand()%256/255.0, rand()%256/255.0);
 				DrawGLPoly (p);
 				rs_brushpasses++;
@@ -162,7 +164,7 @@ void R_DrawSequentialPoly (msurface_t *s)
 			return;
 		}
 
-		srand((unsigned int) (size_t) s->polys);
+		srand((unsigned int) (uintptr_t) s->polys);
 		glColor3f (rand()%256/255.0, rand()%256/255.0, rand()%256/255.0);
 		DrawGLPoly (s->polys);
 		rs_brushpasses++;
@@ -503,7 +505,7 @@ void R_DrawBrushModel (entity_t *e)
 	msurface_t	*psurf;
 	float		dot;
 	mplane_t	*pplane;
-	model_t		*clmodel;
+	qmodel_t	*clmodel;
 
 	if (R_CullModelForEntity(e))
 		return;
@@ -536,14 +538,26 @@ void R_DrawBrushModel (entity_t *e)
 				(!cl_dlights[k].radius))
 				continue;
 
-			R_MarkLights (&cl_dlights[k], 1<<k,
+			R_MarkLights (&cl_dlights[k], k,
 				clmodel->nodes + clmodel->hulls[0].firstclipnode);
 		}
 	}
 
     glPushMatrix ();
 	e->angles[0] = -e->angles[0];	// stupid quake bug
+	if (gl_zfix.value)
+	{
+		e->origin[0] -= DIST_EPSILON;
+		e->origin[1] -= DIST_EPSILON;
+		e->origin[2] -= DIST_EPSILON;
+	}
 	R_RotateForEntity (e->origin, e->angles);
+	if (gl_zfix.value)
+	{
+		e->origin[0] += DIST_EPSILON;
+		e->origin[1] += DIST_EPSILON;
+		e->origin[2] += DIST_EPSILON;
+	}
 	e->angles[0] = -e->angles[0];	// stupid quake bug
 
 	//
@@ -584,7 +598,7 @@ void R_DrawBrushModel_ShowTris (entity_t *e)
 	msurface_t	*psurf;
 	float		dot;
 	mplane_t	*pplane;
-	model_t		*clmodel;
+	qmodel_t	*clmodel;
 	glpoly_t	*p;
 
 	if (R_CullModelForEntity(e))
@@ -747,7 +761,7 @@ int AllocBlock (int w, int h, int *x, int *y)
 
 
 mvertex_t	*r_pcurrentvertbase;
-model_t		*currentmodel;
+qmodel_t	*currentmodel;
 
 int	nColinElim;
 
@@ -779,7 +793,7 @@ void BuildSurfaceDisplayList (msurface_t *fa)
 {
 	int			i, lindex, lnumverts;
 	medge_t		*pedges, *r_pedge;
-	int			vertpage;
+//	int		vertpage;
 	float		*vec;
 	float		s, t;
 	glpoly_t	*poly;
@@ -787,7 +801,7 @@ void BuildSurfaceDisplayList (msurface_t *fa)
 // reconstruct the polygon
 	pedges = currentmodel->edges;
 	lnumverts = fa->numedges;
-	vertpage = 0;
+//	vertpage = 0;
 
 	//
 	// draw texture
@@ -859,7 +873,7 @@ void GL_BuildLightmaps (void)
 	char	name[16];
 	byte	*data;
 	int		i, j;
-	model_t	*m;
+	qmodel_t	*m;
 
 	memset (allocated, 0, sizeof(allocated));
 
@@ -956,7 +970,7 @@ void R_AddDynamicLights (msurface_t *surf)
 
 	for (lnum=0 ; lnum<MAX_DLIGHTS ; lnum++)
 	{
-		if ( !(surf->dlightbits & (1<<lnum) ) )
+		if (! (surf->dlightbits[lnum >> 5] & (1U << (lnum & 31))))
 			continue;		// not lit by this light
 
 		rad = cl_dlights[lnum].radius;
@@ -1142,7 +1156,7 @@ R_RebuildAllLightmaps -- johnfitz -- called when gl_overbright gets toggled
 void R_RebuildAllLightmaps (void)
 {
 	int			i, j;
-	model_t		*mod;
+	qmodel_t	*mod;
 	msurface_t	*fa;
 	byte		*base;
 
