@@ -40,8 +40,8 @@ int			r_numparticles;
 gltexture_t *particletexture, *particletexture1, *particletexture2, *particletexture3, *particletexture4; //johnfitz
 float texturescalefactor; //johnfitz -- compensate for apparent size of different particle textures
 
-cvar_t	r_particles = {"r_particles","1", true}; //johnfitz
-cvar_t	r_quadparticles = {"r_quadparticles","1", true}; //johnfitz
+cvar_t	r_particles = {"r_particles","1", CVAR_ARCHIVE}; //johnfitz
+cvar_t	r_quadparticles = {"r_quadparticles","1", CVAR_ARCHIVE}; //johnfitz
 
 /*
 ===============
@@ -122,7 +122,7 @@ void R_InitParticleTextures (void)
 R_SetParticleTexture_f -- johnfitz
 ===============
 */
-void R_SetParticleTexture_f (void)
+static void R_SetParticleTexture_f (cvar_t *var)
 {
 	switch ((int)(r_particles.value))
 	{
@@ -166,8 +166,9 @@ void R_InitParticles (void)
 	particles = (particle_t *)
 			Hunk_AllocName (r_numparticles * sizeof(particle_t), "particles");
 
-	Cvar_RegisterVariable (&r_particles, R_SetParticleTexture_f); //johnfitz
-	Cvar_RegisterVariable (&r_quadparticles, NULL); //johnfitz
+	Cvar_RegisterVariable (&r_particles); //johnfitz
+	Cvar_SetCallback (&r_particles, R_SetParticleTexture_f);
+	Cvar_RegisterVariable (&r_quadparticles); //johnfitz
 
 	R_InitParticleTextures (); //johnfitz
 }
@@ -187,24 +188,25 @@ float	timescale = 0.01;
 
 void R_EntityParticles (entity_t *ent)
 {
-	int			count;
-	int			i;
+	int		i;
 	particle_t	*p;
 	float		angle;
-	float		sr, sp, sy, cr, cp, cy;
+	float		sp, sy, cp, cy;
+//	float		sr, cr;
+//	int		count;
 	vec3_t		forward;
 	float		dist;
 
 	dist = 64;
-	count = 50;
+//	count = 50;
 
 	if (!avelocities[0][0])
 	{
-	for (i=0 ; i<NUMVERTEXNORMALS*3 ; i++)
-	avelocities[0][i] = (rand()&255) * 0.01;
+		for (i = 0; i < NUMVERTEXNORMALS*3; i++)
+			avelocities[0][i] = (rand() & 255) * 0.01;
 	}
 
-	for (i=0 ; i<NUMVERTEXNORMALS ; i++)
+	for (i = 0; i < NUMVERTEXNORMALS; i++)
 	{
 		angle = cl.time * avelocities[i][0];
 		sy = sin(angle);
@@ -213,8 +215,8 @@ void R_EntityParticles (entity_t *ent)
 		sp = sin(angle);
 		cp = cos(angle);
 		angle = cl.time * avelocities[i][2];
-		sr = sin(angle);
-		cr = cos(angle);
+	//	sr = sin(angle);
+	//	cr = cos(angle);
 
 		forward[0] = cp*cy;
 		forward[1] = cp*sy;
@@ -268,7 +270,7 @@ void R_ReadPointFile_f (void)
 	particle_t	*p;
 	char	name[MAX_OSPATH];
 
-	sprintf (name,"maps/%s.pts", sv.name);
+	q_snprintf (name, sizeof(name), "maps/%s.pts", sv.name);
 
 	COM_FOpenFile (name, &f, NULL);
 	if (!f)
