@@ -2,7 +2,7 @@
  * Ogg/Vorbis streaming music support, loosely based on several open source
  * Quake engine based projects with many modifications.
  *
- * Copyright (C) 2010-2011 O.Sezer <sezero@users.sourceforge.net>
+ * Copyright (C) 2010-2012 O.Sezer <sezero@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,6 +63,8 @@ static const ov_callbacks ovc_qfs =
 	(long (*)(void *))				FS_ftell
 };
 
+#define OV_OPEN_CALLBACKS		ov_open_callbacks
+
 static qboolean S_OGG_CodecInitialize (void)
 {
 	return true;
@@ -84,13 +86,12 @@ static snd_stream_t *S_OGG_CodecOpenStream (const char *filename)
 		return NULL;
 
 	ovFile = (OggVorbis_File *) Z_Malloc(sizeof(OggVorbis_File));
-	res = ov_open_callbacks(&stream->fh, ovFile, NULL, 0, ovc_qfs);
-	if (res < 0)
+	res = OV_OPEN_CALLBACKS(&stream->fh, ovFile, NULL, 0, ovc_qfs);
+	if (res != 0)
 	{
-		Con_Printf("%s is not a valid Ogg Vorbis file (error %i).\n", filename, res);
-		Z_Free(ovFile);
-		S_CodecUtilClose(&stream);
-		return NULL;
+		Con_Printf("%s is not a valid Ogg Vorbis file (error %i).\n",
+				filename, res);
+		goto _fail;
 	}
 
 	stream->priv = ovFile;
@@ -98,20 +99,21 @@ static snd_stream_t *S_OGG_CodecOpenStream (const char *filename)
 	if (!ov_seekable(ovFile))
 	{
 		Con_Printf("OGG_Open: stream %s not seekable.\n", filename);
-		ov_clear(ovFile);
-		Z_Free(ovFile);
-		S_CodecUtilClose(&stream);
-		return NULL;
+		goto _fail;
 	}
 
 	ogg_info = ov_info(ovFile, 0);
 	if (!ogg_info)
 	{
 		Con_Printf("Unable to get stream information for %s.\n", filename);
-		ov_clear(ovFile);
-		Z_Free(ovFile);
-		S_CodecUtilClose(&stream);
-		return NULL;
+		goto _fail;
+	}
+
+	if (ogg_info->channels != 1 && ogg_info->channels != 2)
+	{
+		Con_Printf("Unsupported number of channels %d in %s\n",
+					ogg_info->channels, filename);
+		goto _fail;
 	}
 
 	stream->info.rate = ogg_info->rate;
@@ -119,6 +121,12 @@ static snd_stream_t *S_OGG_CodecOpenStream (const char *filename)
 	stream->info.width = OGG_SAMPLEWIDTH;
 
 	return stream;
+_fail:
+	if (res == 0)
+		ov_clear(ovFile);
+	Z_Free(ovFile);
+	S_CodecUtilClose(&stream);
+	return NULL;
 }
 
 static int S_OGG_CodecReadStream (snd_stream_t *stream, int bytes, void *buffer)
