@@ -20,20 +20,16 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 // sv_main.c -- server main program
 
-#include "q_stdinc.h"
-#include "arch_def.h"
-#include "net_sys.h"	/* for net_defs.h */
 #include "quakedef.h"
-#include "net_defs.h"	/* for struct qsocket_s details */
 
-server_t		sv;
+server_t	sv;
 server_static_t	svs;
 
-char	localmodels[MAX_MODELS][6];			// inline model names for precache
+static char	localmodels[MAX_MODELS][8];	// inline model names for precache
 
-int sv_protocol = PROTOCOL_FITZQUAKE; //johnfitz
+int		sv_protocol = PROTOCOL_FITZQUAKE; //johnfitz
 
-extern qboolean		pr_alpha_supported; //johnfitz
+extern qboolean	pr_alpha_supported; //johnfitz
 
 //============================================================================
 
@@ -67,6 +63,7 @@ void SV_Protocol_f (void)
 		break;
 	}
 }
+
 /*
 ===============
 SV_Init
@@ -78,6 +75,7 @@ void SV_Init (void)
 	extern	cvar_t	sv_maxvelocity;
 	extern	cvar_t	sv_gravity;
 	extern	cvar_t	sv_nostep;
+	extern	cvar_t	sv_freezenonclients;
 	extern	cvar_t	sv_friction;
 	extern	cvar_t	sv_edgefriction;
 	extern	cvar_t	sv_stopspeed;
@@ -87,17 +85,21 @@ void SV_Init (void)
 	extern	cvar_t	sv_aim;
 	extern	cvar_t	sv_altnoclip; //johnfitz
 
-	Cvar_RegisterVariable (&sv_maxvelocity, NULL);
-	Cvar_RegisterVariable (&sv_gravity, NULL);
-	Cvar_RegisterVariable (&sv_friction, NULL);
-	Cvar_RegisterVariable (&sv_edgefriction, NULL);
-	Cvar_RegisterVariable (&sv_stopspeed, NULL);
-	Cvar_RegisterVariable (&sv_maxspeed, NULL);
-	Cvar_RegisterVariable (&sv_accelerate, NULL);
-	Cvar_RegisterVariable (&sv_idealpitchscale, NULL);
-	Cvar_RegisterVariable (&sv_aim, NULL);
-	Cvar_RegisterVariable (&sv_nostep, NULL);
-	Cvar_RegisterVariable (&sv_altnoclip, NULL); //johnfitz
+	Cvar_RegisterVariable (&sv_maxvelocity);
+	Cvar_RegisterVariable (&sv_gravity);
+	Cvar_RegisterVariable (&sv_friction);
+	Cvar_SetCallback (&sv_gravity, Host_Callback_Notify);
+	Cvar_SetCallback (&sv_friction, Host_Callback_Notify);
+	Cvar_RegisterVariable (&sv_edgefriction);
+	Cvar_RegisterVariable (&sv_stopspeed);
+	Cvar_RegisterVariable (&sv_maxspeed);
+	Cvar_SetCallback (&sv_maxspeed, Host_Callback_Notify);
+	Cvar_RegisterVariable (&sv_accelerate);
+	Cvar_RegisterVariable (&sv_idealpitchscale);
+	Cvar_RegisterVariable (&sv_aim);
+	Cvar_RegisterVariable (&sv_nostep);
+	Cvar_RegisterVariable (&sv_freezenonclients);
+	Cvar_RegisterVariable (&sv_altnoclip); //johnfitz
 
 	Cmd_AddCommand ("sv_protocol", &SV_Protocol_f); //johnfitz
 
@@ -323,7 +325,7 @@ void SV_ConnectClient (int clientnum)
 
 	client = svs.clients + clientnum;
 
-	Con_DPrintf ("Client %s connected\n", client->netconnection->address);
+	Con_DPrintf ("Client %s connected\n", NET_QSocketGetAddressString(client->netconnection));
 
 	edictnum = clientnum+1;
 
@@ -344,7 +346,6 @@ void SV_ConnectClient (int clientnum)
 	client->message.data = client->msgbuf;
 	client->message.maxsize = sizeof(client->msgbuf);
 	client->message.allowoverflow = true;		// we can catch it
-	client->privileged = false;
 
 	if (sv.loadgame)
 		memcpy (client->spawn_parms, spawn_parms, sizeof(spawn_parms));
@@ -431,7 +432,7 @@ crosses a waterline.
 int		fatbytes;
 byte	fatpvs[MAX_MAP_LEAFS/8];
 
-void SV_AddToFatPVS (vec3_t org, mnode_t *node, model_t *worldmodel) //johnfitz -- added worldmodel as a parameter
+void SV_AddToFatPVS (vec3_t org, mnode_t *node, qmodel_t *worldmodel) //johnfitz -- added worldmodel as a parameter
 {
 	int		i;
 	byte	*pvs;
@@ -474,7 +475,7 @@ Calculates a PVS that is the inclusive or of all leafs within 8 pixels of the
 given point.
 =============
 */
-byte *SV_FatPVS (vec3_t org, model_t *worldmodel) //johnfitz -- added worldmodel as a parameter
+byte *SV_FatPVS (vec3_t org, qmodel_t *worldmodel) //johnfitz -- added worldmodel as a parameter
 {
 	fatbytes = (worldmodel->numleafs+31)>>3;
 	Q_memset (fatpvs, 0, fatbytes);
@@ -489,7 +490,7 @@ SV_VisibleToClient -- johnfitz
 PVS test encapsulated in a nice function
 =============
 */
-qboolean SV_VisibleToClient (edict_t *client, edict_t *test, model_t *worldmodel)
+qboolean SV_VisibleToClient (edict_t *client, edict_t *test, qmodel_t *worldmodel)
 {
 	byte	*pvs;
 	vec3_t	org;
@@ -914,7 +915,7 @@ qboolean SV_SendClientDatagram (client_t *client)
 	msg.cursize = 0;
 
 	//johnfitz -- if client is nonlocal, use smaller max size so packets aren't fragmented
-	if (Q_strcmp (client->netconnection->address, "LOCAL") != 0)
+	if (Q_strcmp(NET_QSocketGetAddressString(client->netconnection), "LOCAL") != 0)
 		msg.maxsize = DATAGRAM_MTU;
 	//johnfitz
 
@@ -1233,7 +1234,7 @@ void SV_SendReconnect (void)
 	MSG_WriteString (&msg, "reconnect\n");
 	NET_SendToAll (&msg, 5.0);
 
-	if (cls.state != ca_dedicated)
+	if (!isDedicated)
 		Cmd_ExecuteString ("reconnect\n", src_command);
 }
 
@@ -1300,7 +1301,7 @@ void SV_SpawnServer (const char *server)
 // make cvars consistant
 //
 	if (coop.value)
-		Cvar_SetValue ("deathmatch", 0);
+		Cvar_Set ("deathmatch", "0");
 	current_skill = (int)(skill.value + 0.5);
 	if (current_skill < 0)
 		current_skill = 0;
@@ -1312,11 +1313,10 @@ void SV_SpawnServer (const char *server)
 //
 // set up the new server
 //
+	//memset (&sv, 0, sizeof(sv));
 	Host_ClearMemory ();
 
-	memset (&sv, 0, sizeof(sv));
-
-	strcpy (sv.name, server);
+	q_strlcpy (sv.name, server, sizeof(sv.name));
 
 	sv.protocol = sv_protocol; // johnfitz
 
@@ -1324,6 +1324,7 @@ void SV_SpawnServer (const char *server)
 	PR_LoadProgs ();
 
 // allocate server memory
+	/* Host_ClearMemory() called above already cleared the whole sv structure */
 	sv.max_edicts = CLAMP (MIN_EDICTS,(int)max_edicts.value,MAX_EDICTS); //johnfitz -- max_edicts cvar
 	sv.edicts = (edict_t *) Hunk_AllocName (sv.max_edicts*pr_edict_size, "edicts");
 
@@ -1352,8 +1353,8 @@ void SV_SpawnServer (const char *server)
 
 	sv.time = 1.0;
 
-	strcpy (sv.name, server);
-	sprintf (sv.modelname,"maps/%s.bsp", server);
+	q_strlcpy (sv.name, server, sizeof(sv.name));
+	q_snprintf (sv.modelname, sizeof(sv.modelname), "maps/%s.bsp", server);
 	sv.worldmodel = Mod_ForName (sv.modelname, false);
 	if (!sv.worldmodel)
 	{
